#ifndef REPLACE_STRING_H
#define REPLACE_STRING_H
/*
 * http://www.sasaraan.net/program/cpp/cpp_find.html
 * http://www.geocities.jp/debu0510/personal/c_moji.html
 * 辺りが参考になった
*/

#include <stdlib.h>
#include <string.h>

// 関数プロトタイプ
static inline void replace_string(char *buf, char *before, char *after, int buf_len) __attribute__((always_inline));

/*******************************************************************************
 * 文字列を置換する。
 * バッファサイズを考慮していない。置換後の文字列がバッファサイズを超える場合、
 * 多分落ちる。超えることは無いはずだが…
*******************************************************************************/
static inline void replace_string(char *buf, char *before, char *after, int buf_len)
{
	char *tmp = buf;

	for(;;)
	{
		char *point;
		size_t before_len;
		size_t after_len;

		before_len = strlen(before);
		after_len = strlen(after);

		if((point = strstr(tmp, before)) == NULL)
		{
			break;
		}

		tmp = point;
		memmove(point + after_len, point + before_len, buf_len - (point + before_len - buf) + 1);
		memcpy(point, after, after_len);
		tmp = tmp + after_len;
	}
}

#endif
